pub fn delete_vault(signer: Pubkey) -> InstructionExpand description
Delete the vault account (for re-initialization after schema changes). WARNING: This is destructive and should only be used during development/testing.
pub fn delete_vault(signer: Pubkey) -> InstructionDelete the vault account (for re-initialization after schema changes). WARNING: This is destructive and should only be used during development/testing.